Learn R Programming

mgwnbr (version 0.3.0)

georgia: Georgia dataset

Description

The Georgia census data set from Fotheringham et al. (2002) in dataframe format.

Usage

data(georgia)

Arguments

Format

A data frame with with 159 observations on the following 13 variables:

  • AreaKey - an identification number for each county

  • Latitude - the latitude of the county centroid

  • Longitud - the longitude of the county centroid

  • TotPop90 - population of the county in 1990

  • PctRural - percentage of the county population defined as rural

  • PctBach - percentage of the county population with a bachelors degree

  • PctEld - percentage of the county population aged 65 or over

  • PctFB - percentage of the county population born outside the US

  • PctPov - percentage of the county population living below the poverty line

  • PctBlack - percentage of the county population who are black

  • ID - a numeric vector of IDs

  • X - a numeric vector of x coordinates

  • Y - a numeric vector of y coordinates